@@ -1,10 +1,8 @@
-
 from .base_calibrations import BaseCalibration
 
 
 class IbeltCalibation(BaseCalibration):
-    """Calibrations performed inside the utube
-    """
+    """Calibrations performed inside the utube"""
 
     _ALIAS = "ibelt_calibrations"
 
