@@ -1,4 +1,3 @@
-
 from typing import Literal
 
 import rframe
@@ -7,12 +6,11 @@ from .base_calibrations import BaseCalibration
 
 
 class UtubeCalibration(BaseCalibration):
-    """Calibrations performed inside the utube
-    """
+    """Calibrations performed inside the utube"""
 
     _ALIAS = "utube_calibrations"
 
-    tube: Literal['top','bottom'] = rframe.Index()
-    direction: Literal['cw','ccw'] = rframe.Index()
+    tube: Literal["top", "bottom"] = rframe.Index()
+    direction: Literal["cw", "ccw"] = rframe.Index()
 
     depth_cm: float
